@@ -28,6 +28,7 @@
 #include <hildon/hildon-program.h>
 #include <hildon/hildon-note.h>
 #include <hildon/hildon-banner.h>
+#include <hildon/hildon-entry.h>
 #include <gtk/gtk.h>
 #include <libosso.h>
 #include <sys/socket.h>
@@ -635,6 +636,7 @@ window_cb_key_press(GtkWidget* widget, GdkEventKey *event)
               send_request("IrDispatchCommand CK_EAST\r\n");
               break;
           case GDK_Return:
+	  case GDK_KP_Enter:
               send_request("IrDispatchCommand CK_SELECT\r\n");
               break;
           case GDK_F7:
@@ -644,9 +646,12 @@ window_cb_key_press(GtkWidget* widget, GdkEventKey *event)
               send_request("IrDispatchCommand CK_VOLUME_DOWN\r\n");
               break;
           case GDK_F6:
+	  case GDK_M:
+	  case GDK_m:
               send_request("IrDispatchCommand CK_MENU\r\n");
               break;
           case GDK_Escape:
+	  case GDK_BackSpace:
               send_request("IrDispatchCommand CK_EXIT\r\n");
               break;
           default:
@@ -962,9 +967,9 @@ menu_cb_connect_new(GtkAction *action)
                                          GTK_RESPONSE_CANCEL,
                                          NULL);
     device_label = gtk_label_new (_("Soundbridge Name"));
-    device_name = gtk_entry_new();
+    device_name = hildon_entry_new (HILDON_SIZE_AUTO);
     ip_label = gtk_label_new(_("Soundbridge IP Address"));
-    ip_value = gtk_entry_new();
+    ip_value = hildon_entry_new (HILDON_SIZE_AUTO);
     /* Add the label, and show everything we've added to the dialog. */
     gtk_container_add(GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), device_label);
     gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), device_name);
@@ -974,8 +979,8 @@ menu_cb_connect_new(GtkAction *action)
     gint result = gtk_dialog_run (GTK_DIALOG(dialog));
     switch (result) {
       case GTK_RESPONSE_OK:
-        sb_name = gtk_entry_get_text(GTK_ENTRY(device_name));
-        ip_addr = gtk_entry_get_text(GTK_ENTRY(ip_value));
+	sb_name = hildon_entry_get_text(HILDON_ENTRY(device_name));
+        ip_addr = hildon_entry_get_text(HILDON_ENTRY(ip_value));
         name_len = strlen(sb_name);
         ip_len = strlen(ip_addr);
     
@@ -994,11 +999,13 @@ menu_cb_connect_new(GtkAction *action)
         }
 
         if (connect_status == FALSE) {
-          char *err_msg = (char *)malloc(strlen(ip_addr) + 25);
+	  char *err_msg = (char *)malloc(strlen(ip_addr) + 25);
           if (err_msg != NULL) {
-            sprintf(err_msg, "Unable to connect to %s", ip_addr);
-            gtk_widget_destroy(dialog);
-            popup_error(window, err_msg);
+	    if (ip_len > 0) {
+              sprintf(err_msg, "Unable to connect to %s", ip_addr);
+              gtk_widget_destroy(dialog);
+              popup_error(window, err_msg);
+	    }
             free(err_msg);
           } else {
             gtk_widget_destroy(dialog);
